@@ -1,5 +1,9 @@
+from math import isnan
+
 from dagster import check, seven
-from dagster.core.definitions.events import (
+from dagster.core.definitions.event_metadata import (
+    DagsterAssetMetadataEntryData,
+    DagsterPipelineRunMetadataEntryData,
     EventMetadataEntry,
     FloatMetadataEntryData,
     IntMetadataEntryData,
@@ -25,6 +29,8 @@ def iterate_metadata_entries(metadata_entries):
         GrapheneEventPythonArtifactMetadataEntry,
         GrapheneEventTextMetadataEntry,
         GrapheneEventUrlMetadataEntry,
+        GrapheneEventPipelineRunMetadataEntry,
+        GrapheneEventAssetMetadataEntry,
     )
 
     check.list_param(metadata_entries, "metadata_entries", of_type=EventMetadataEntry)
@@ -67,16 +73,41 @@ def iterate_metadata_entries(metadata_entries):
                 name=metadata_entry.entry_data.name,
             )
         elif isinstance(metadata_entry.entry_data, FloatMetadataEntryData):
+            float_val = metadata_entry.entry_data.value
+
+            # coerce NaN to null
+            if isnan(float_val):
+                float_val = None
+
             yield GrapheneEventFloatMetadataEntry(
                 label=metadata_entry.label,
                 description=metadata_entry.description,
-                floatValue=metadata_entry.entry_data.value,
+                floatValue=float_val,
             )
         elif isinstance(metadata_entry.entry_data, IntMetadataEntryData):
+            # coerce > 32 bit ints to null
+            int_val = None
+            if metadata_entry.entry_data.value.bit_length() <= 32:
+                int_val = metadata_entry.entry_data.value
+
             yield GrapheneEventIntMetadataEntry(
                 label=metadata_entry.label,
                 description=metadata_entry.description,
-                intValue=metadata_entry.entry_data.value,
+                intValue=int_val,
+                # make string representation available to allow for > 32bit int
+                intRepr=str(metadata_entry.entry_data.value),
+            )
+        elif isinstance(metadata_entry.entry_data, DagsterPipelineRunMetadataEntryData):
+            yield GrapheneEventPipelineRunMetadataEntry(
+                label=metadata_entry.label,
+                description=metadata_entry.description,
+                runId=metadata_entry.entry_data.run_id,
+            )
+        elif isinstance(metadata_entry.entry_data, DagsterAssetMetadataEntryData):
+            yield GrapheneEventAssetMetadataEntry(
+                label=metadata_entry.label,
+                description=metadata_entry.description,
+                assetKey=metadata_entry.entry_data.asset_key,
             )
         else:
             # skip rest for now
@@ -106,18 +137,20 @@ def from_dagster_event_record(event_record, pipeline_name):
         GrapheneHookErroredEvent,
         GrapheneHookSkippedEvent,
         GrapheneLoadedInputEvent,
+        GrapheneLogsCapturedEvent,
         GrapheneObjectStoreOperationEvent,
         GraphenePipelineCanceledEvent,
         GraphenePipelineCancelingEvent,
         GraphenePipelineDequeuedEvent,
         GraphenePipelineEnqueuedEvent,
         GraphenePipelineFailureEvent,
-        GraphenePipelineInitFailureEvent,
         GraphenePipelineStartEvent,
         GraphenePipelineStartingEvent,
         GraphenePipelineSuccessEvent,
         GrapheneStepExpectationResultEvent,
         GrapheneStepMaterializationEvent,
+        GrapheneAlertStartEvent,
+        GrapheneAlertSuccessEvent,
     )
 
     # Lots of event types. Pylint thinks there are too many branches
@@ -198,13 +231,10 @@ def from_dagster_event_record(event_record, pipeline_name):
             else None,
             **basic_params,
         )
-
-    elif dagster_event.event_type == DagsterEventType.PIPELINE_INIT_FAILURE:
-        return GraphenePipelineInitFailureEvent(
-            pipelineName=pipeline_name,
-            error=GraphenePythonError(dagster_event.pipeline_init_failure_data.error),
-            **basic_params,
-        )
+    elif dagster_event.event_type == DagsterEventType.ALERT_START:
+        return GrapheneAlertStartEvent(pipelineName=pipeline_name, **basic_params)
+    elif dagster_event.event_type == DagsterEventType.ALERT_SUCCESS:
+        return GrapheneAlertSuccessEvent(pipelineName=pipeline_name, **basic_params)
     elif dagster_event.event_type == DagsterEventType.HANDLED_OUTPUT:
         return GrapheneHandledOutputEvent(
             output_name=dagster_event.event_specific_data.output_name,
@@ -243,6 +273,13 @@ def from_dagster_event_record(event_record, pipeline_name):
         return GrapheneHookErroredEvent(
             error=GraphenePythonError(dagster_event.hook_errored_data.error), **basic_params
         )
+    elif dagster_event.event_type == DagsterEventType.LOGS_CAPTURED:
+        return GrapheneLogsCapturedEvent(
+            logKey=dagster_event.logs_captured_data.log_key,
+            stepKeys=dagster_event.logs_captured_data.step_keys,
+            pid=dagster_event.pid,
+            **basic_params,
+        )
     else:
         raise Exception(
             "Unknown DAGSTER_EVENT type {inner_type} found in logs".format(
