@@ -1,4 +1,4 @@
-from dagster.core.host_representation import RepositoryLocationHandleManager
+from dagster.cli.workspace.dynamic_workspace import DynamicWorkspace
 from dagster.core.host_representation.grpc_server_registry import ProcessGrpcServerRegistry
 from dagster.daemon import get_default_daemon_logger
 from dagster.daemon.sensor import execute_sensor_iteration
@@ -33,18 +33,18 @@ query JobQuery($jobSelector: JobSelector!) {
 
 
 def _create_sensor_tick(instance):
-    with ProcessGrpcServerRegistry(wait_for_processes_on_exit=True) as grpc_server_registry:
-        with RepositoryLocationHandleManager(grpc_server_registry) as handle_manager:
+    with ProcessGrpcServerRegistry() as grpc_server_registry:
+        with DynamicWorkspace(grpc_server_registry) as workspace:
             list(
                 execute_sensor_iteration(
-                    instance, get_default_daemon_logger("SensorDaemon"), handle_manager
+                    instance, get_default_daemon_logger("SensorDaemon"), workspace
                 )
             )
 
 
 class TestNextTickRepository(
     make_graphql_context_test_suite(
-        context_variants=GraphQLContextVariant.all_readonly_variants(),
+        context_variants=GraphQLContextVariant.all_non_launchable_variants(),
     )
 ):
     def test_schedule_next_tick(self, graphql_context):
